@@ -8,6 +8,8 @@ try:
     from selenium.webdriver.support import expected_conditions as EC
     from selenium.webdriver.common.by import By
     from selenium.common.exceptions import TimeoutException
+    from selenium.webdriver.chrome.options import Options
+
 except ModuleNotFoundError:
     cmd('pip3 install selenium')
     from selenium import webdriver
@@ -17,18 +19,20 @@ except ModuleNotFoundError:
     from selenium.webdriver.support import expected_conditions as EC
     from selenium.webdriver.common.by import By
     from selenium.common.exceptions import TimeoutException
-        
+    from selenium.webdriver.chrome.options import Options
+
+
 class WhatsappAPI():
 
     @classmethod
     def setup(self):
         options = webdriver.ChromeOptions()
-        options.add_argument('user-data-dir=%USERPROFILE%\\AppData\\Local\\Google\\Chrome\\User Data\\Default')
+        options.add_argument('--user-data-dir=C:/Users/enzon/AppData/Local/Google/Chrome/User Data/Default')
         self.driver = webdriver.Chrome(options=options)
         self.driver.get('https://web.whatsapp.com')
 
     @classmethod
-    def send_text_message(self, contact, message):
+    def find_contact(self, contact):
         searchbox = self.driver.find_element_by_xpath('//*[@id="side"]/div[1]/div/label/div/div[2]')
         searchbox.click()
         searchbox.send_keys(Keys.CONTROL, 'a', Keys.BACKSPACE)
@@ -36,6 +40,8 @@ class WhatsappAPI():
         con = self.driver.find_element_by_xpath(f'//*[@title="{contact}"]')
         con.click()
 
+    @classmethod
+    def send_text_message(self, message):
         box = self.driver.find_element_by_xpath('//*[@id="main"]/footer/div[1]/div[2]/div/div[2]')
         box.click()
         box.send_keys(message)
@@ -83,13 +89,7 @@ class WhatsappAPI():
         self.driver.quit()
 
     @classmethod
-    def send_image(self, contact, path):
-        searchbox = self.driver.find_element_by_xpath('//*[@id="side"]/div[1]/div/label/div/div[2]')
-        searchbox.click()
-        searchbox.send_keys(Keys.CONTROL, 'a', Keys.BACKSPACE)
-        searchbox.send_keys(contact)
-        con = self.driver.find_element_by_xpath(f'//*[@title="{contact}"]')
-        con.click()
+    def send_image(self, path):
 
         clipbox = self.driver.find_element_by_xpath('//*[@id="main"]/footer/div[1]/div[1]/div[2]/div/div')
         clipbox.click()
@@ -103,13 +103,7 @@ class WhatsappAPI():
         sendbt.click()
 
     @classmethod
-    def send_document(self, contact, path):
-        searchbox = self.driver.find_element_by_xpath('//*[@id="side"]/div[1]/div/label/div/div[2]')
-        searchbox.click()
-        searchbox.send_keys(Keys.CONTROL, 'a', Keys.BACKSPACE)
-        searchbox.send_keys(contact)
-        con = self.driver.find_element_by_xpath(f'//*[@title="{contact}"]')
-        con.click()
+    def send_document(self, path):
 
         clipbox = self.driver.find_element_by_xpath('//*[@id="main"]/footer/div[1]/div[1]/div[2]/div/div')
         clipbox.click()
@@ -123,13 +117,7 @@ class WhatsappAPI():
         sendbt.click()
 
     @classmethod
-    def take_shot(self, contact):
-        searchbox = self.driver.find_element_by_xpath('//*[@id="side"]/div[1]/div/label/div/div[2]')
-        searchbox.click()
-        searchbox.send_keys(Keys.CONTROL, 'a', Keys.BACKSPACE)
-        searchbox.send_keys(contact)
-        con = self.driver.find_element_by_xpath(f'//*[@title="{contact}"]')
-        con.click()
+    def take_shot(self):
 
         clipbox = self.driver.find_element_by_xpath('//*[@id="main"]/footer/div[1]/div[1]/div[2]/div/div/span')
         clipbox.click()
@@ -150,13 +138,7 @@ class WhatsappAPI():
         sendbtn.click()
 
     @classmethod
-    def send_contact(self, contact, sendthiscontact):
-        searchbox = self.driver.find_element_by_xpath('//*[@id="side"]/div[1]/div/label/div/div[2]')
-        searchbox.click()
-        searchbox.send_keys(Keys.CONTROL, 'a', Keys.BACKSPACE)
-        searchbox.send_keys(contact)
-        con = self.driver.find_element_by_xpath(f'//*[@title="{contact}"]')
-        con.click()
+    def send_contact(self, sendthiscontact):
 
         wait(0.4)
 
@@ -190,13 +172,7 @@ class WhatsappAPI():
         sendbtn2.click()
 
     @classmethod
-    def block_contact(self, contact):
-        searchbox = self.driver.find_element_by_xpath('//*[@id="side"]/div[1]/div/label/div/div[2]')
-        searchbox.click()
-        searchbox.send_keys(Keys.CONTROL, 'a', Keys.BACKSPACE)
-        searchbox.send_keys(contact)
-        con = self.driver.find_element_by_xpath(f'//*[@title="{contact}"]')
-        con.click()
+    def block_contact(self):
 
         info = self.driver.find_element_by_xpath('//*[@id="main"]/header/div[2]/div/div/span')
         info.click()
@@ -208,13 +184,7 @@ class WhatsappAPI():
         confirmblok.click()
 
     @classmethod
-    def unblock_contact(self, contact):
-        searchbox = self.driver.find_element_by_xpath('//*[@id="side"]/div[1]/div/label/div/div[2]')
-        searchbox.click()
-        searchbox.send_keys(Keys.CONTROL, 'a', Keys.BACKSPACE)
-        searchbox.send_keys(contact)
-        con = self.driver.find_element_by_xpath(f'//*[@title="{contact}"]')
-        con.click()
+    def unblock_contact(self):
 
         info = self.driver.find_element_by_xpath('//*[@id="main"]/header/div[2]/div/div/span')
         info.click()
